@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # @Author: sijanonly
 # @Date:   2018-03-15 12:39:10
-# @Last Modified time: 2018-03-15 15:01:30
+# @Last Modified time: 2018-03-19 11:07:11
 
 from .base import SolutionByTextAPI
 
@@ -13,13 +13,15 @@ class CarrierLookUp(SolutionByTextAPI):
 
     service_end_point = 'GeneralRSService.svc/GetCarrierLookup'
 
-    def __init__(self, api_key, org_code, phone):
+    def __init__(self, security_token, org_code, stage, phone):
         super().__init__(
-            api_key, org_code,
+            security_token, org_code, stage
         )
         self.phone = phone
 
     def get(self):
+        """
+        """
         arg = {
             "phone": self.phone
         }
